@@ -8,19 +8,15 @@ module Lid_set : Set.S with type elt = Lid.t
 module Stats : Map.S with type key = String.t
 module Uid_map = Shape.Uid.Map
 
-type stat = {
-  mtime : float;
-  size : int;
-  source_digest : string option
-}
+type stat = { mtime : float; size : int; source_digest : string option }
 
-type index = {
-  defs : Lid_set.t Uid_map.t;
-  approximated : Lid_set.t Uid_map.t;
-  cu_shape : (string, Shape.t) Hashtbl.t;
-  stats : stat Stats.t;
-  root_directory: string option;
-}
+type index =
+  { defs : Lid_set.t Uid_map.t;
+    approximated : Lid_set.t Uid_map.t;
+    cu_shape : (string, Shape.t) Hashtbl.t;
+    stats : stat Stats.t;
+    root_directory : string option
+  }
 
 val pp : Format.formatter -> index -> unit
 
@@ -28,10 +24,7 @@ val pp : Format.formatter -> index -> unit
     key is already present the locations are merged. *)
 val add : Lid_set.t Uid_map.t -> Shape.Uid.t -> Lid_set.t -> Lid_set.t Uid_map.t
 
-type file_content =
-  | Cmt of Cmt_format.cmt_infos
-  | Index of index
-  | Unknown
+type file_content = Cmt of Cmt_format.cmt_infos | Index of index | Unknown
 
 val write : file:string -> index -> unit
 val read : file:string -> file_content
